@@ -1,17 +1,18 @@
 """
 store the current version info of the jupyter_core.
 """
+from __future__ import annotations
+
 import re
-from typing import List
 
 # Version string must appear intact for hatch versioning
-__version__ = "5.4.0"
+__version__ = "5.6.0"
 
 # Build up version_info tuple for backwards compatibility
 pattern = r"(?P<major>\d+).(?P<minor>\d+).(?P<patch>\d+)(?P<rest>.*)"
 match = re.match(pattern, __version__)
-assert match is not None  # noqa
-parts: List[object] = [int(match[part]) for part in ["major", "minor", "patch"]]
+assert match is not None
+parts: list[object] = [int(match[part]) for part in ["major", "minor", "patch"]]
 if match["rest"]:
     parts.append(match["rest"])
 version_info = tuple(parts)
